@@ -5,13 +5,13 @@ Author: Nikolay Lysenko
 """
 
 
-from . import adsr_envelopes, effects, timbre, utils, waves
-from .adsr_envelopes import get_envelopes_registry
+from . import effects, envelopes, timbre, timeline, utils, waves
 from .effects import get_effects_registry
+from .envelopes import get_envelopes_registry
 from .synth import synthesize
 
 
 __all__ = [
-    'adsr_envelopes', 'effects', 'timbre', 'utils', 'waves',
+    'effects', 'envelopes', 'timbre', 'timeline', 'utils', 'waves',
     'get_effects_registry', 'get_envelopes_registry', 'synthesize'
 ]
